@@ -26,7 +26,7 @@ from .servers import Server
 __all__ = (
     "App",
     "Middleware",
-    "match_method",
+    "match_method", "match_methods",
     "match_path",
     "match_headers", "match_header",
     "match_params", "match_param",
@@ -36,7 +36,6 @@ __all__ = (
     "default_app", "default_handler", "default_logger",
 )
 
-
 default_app = DefaultApp()
 registry = Registry()
 resolver = ReversedResolver(registry, default_app, default_handler)
@@ -61,6 +60,14 @@ def match_method(method: StrOrAttrMatcher) -> MethodMatcher:
     return MethodMatcher(method, resolver=resolver)
 
 
+def match_methods(*methods: StrOrAttrMatcher) -> AnyMatcher:
+    matchers: List[ResolvableMatcher] = [
+        MethodMatcher(method, resolver=resolver)
+        for method in methods
+    ]
+    return AnyMatcher(matchers, resolver=resolver)
+
+
 def match_path(path: StrOrAttrMatcher) -> PathMatcher:
     return PathMatcher(path, resolver=resolver)
 
