@@ -2,6 +2,7 @@ from types import TracebackType
 from typing import TYPE_CHECKING, Any, List, Optional, Type, Union
 from uuid import UUID, uuid4
 
+from jj.expiration_policy import ExpirationPolicy
 from jj.matchers import LogicalMatcher, RequestMatcher
 
 if TYPE_CHECKING:
@@ -10,7 +11,7 @@ if TYPE_CHECKING:
 else:
     MockType = Any
 
-from ._history import HistoryItem
+from ._history import HistoryAdapterType, HistoryItem, default_history_adapter
 from ._remote_response import RemoteResponseType
 
 __all__ = ("RemoteHandler",)
@@ -20,11 +21,16 @@ class RemoteHandler:
     def __init__(self,
                  mock: MockType,
                  matcher: Union[RequestMatcher, LogicalMatcher],
-                 response: RemoteResponseType) -> None:
+                 response: RemoteResponseType,
+                 expiration_policy: Optional[ExpirationPolicy] = None,
+                 *,
+                 history_adapter: Optional[HistoryAdapterType] = default_history_adapter) -> None:
         self._id = uuid4()
         self._mock = mock
         self._matcher = matcher
         self._response = response
+        self._history_adapter = history_adapter
+        self._expiration_policy = expiration_policy
 
     @property
     def id(self) -> UUID:
@@ -38,6 +44,10 @@ class RemoteHandler:
     def response(self) -> RemoteResponseType:
         return self._response
 
+    @property
+    def expiration_policy(self) -> Optional[ExpirationPolicy]:
+        return self._expiration_policy
+
     async def register(self) -> None:
         await self._mock.register(self)
 
@@ -45,7 +55,10 @@ class RemoteHandler:
         await self._mock.deregister(self)
 
     async def fetch_history(self) -> List[HistoryItem]:
-        return await self._mock.fetch_history(self)
+        history = await self._mock.fetch_history(self)
+        if self._history_adapter:
+            return [self._history_adapter(x) for x in history]
+        return history
 
     async def __aenter__(self) -> None:
         await self.register()
