@@ -4,7 +4,7 @@ if sys.version_info >= (3, 8):
     from unittest import IsolatedAsyncioTestCase as TestCase
     from unittest.mock import AsyncMock
 else:
-    from unittest import TestCase
+    from asynctest import TestCase
     from asynctest.mock import CoroutineMock as AsyncMock
 
 from unittest.mock import Mock, call, sentinel
