@@ -3,7 +3,7 @@ import sys
 if sys.version_info >= (3, 8):
     from unittest import IsolatedAsyncioTestCase as TestCase
 else:
-    from unittest import TestCase
+    from asynctest import TestCase
 
 import pytest
 from aiohttp import FormData
